# Fachschemareferenzen auf Fachstandards und Rahmenwerke abbilden

Im Folgenden wird aufgezeigt, wie Fachschemareferenzen für Fachdatensätze auf bestehende Fachstandards und Rahmenwerke abgebildet werden. Aktuell
werden folgende Fachstandards und Rahmenwerke beschrieben:
- FIM Übertragungsschemata für Anträge auf Basis von FIM Datenfeldern
- XÖV Nachrichten auf Basis von XÖV-konformen Fachstandards

:::note Aufnahme weiterer Fachstandards und Rahmenwerke
Soll ein anderer Fachstandard mit der FIT-Connect Submission API übermittelt werden, können wir gerne die Beschreibung dieser Schemareferenz hier aufnehmen, um diese Informationen einem breiteren Nutzerkreis zugänglich zu machen.
Hierzu bitte einfach ein Issue [hier](https://docs.fitko.de/feedback) aufmachen und gerne schon einen konkreten Vorschlag zuliefern.
:::

## Aufbau Fachschemareferenz

Eine Fachschemareferenz besteht aus zwei Angaben.
- Die `schemaUri` referenziert das zu verwendende Fachschema.
- Der `mimeType` gibt den Datentyp (JSON oder XML) der Fachdaten vor.

Bitte beachten Sie, dass manche Fachschema nur JSON oder XML als Datentyp zulassen.

## FIM Fachschemareferenz

Um ein FIM Fachschema eindeutig zu referenzieren, sind folgende Angaben notwendig:

- **ID** des Stammdatenschemas mit kleinem "s" ("s00000000009" im Beispiel)
- **Version** des Stammdatenschemas ("1.0.0" im Beispiel)
- **Art** des Schemas (JSON- oder XML-Schema)

Für ein JSON-Schema wird die `schemaUri` wie folgt gebildet:
`https://schema.fitko.de/fim/{ID}_{Version}.schema.json`

Für ein XML-Schema wird die `schemaUri` wie folgt gebildet:
`urn:xoev-de:xfall:standard:fim-{ID}_{Version}`

### Beispiel für eine FIM Fachschemareferenz

JSON Schema:
```json
{
  "schemaUri": "https://schema.fitko.de/fim/s00000096_1.0.schema.json",
  "mimeType": "application/json"
}
```

XML Schema:
```json
{
  "schemaUri": "urn:xoev-de:xfall:standard:fim-s00000092_1.0",
  "mimeType": "application/xml"
}
```

## XÖV Fachschemareferenz

Ein XÖV Fachschema wird über folgende Angaben referenziert:
- **Kennung** (ID) des Fachschemas ("urn:xoev-de:bmk:standard:xbau" im Beispiel)
- **Version** des Fachschemas ("2.2" im Beispiel)
- Verwendete **Nachricht** aus dem Fachschema ("baugenehmigung.antrag.0200" im Beispiel)

Beispiel: `urn:xoev-de:bmk:standard:xbau_2.2#baugenehmigung.antrag.0200`

Die `schemaUri` wird wie folgt gebildet:
`{Kennung}_{Version}#{Nachricht}`

### Beispiel für eine XÖV Fachschemareferenz

```json
{
  "schemaUri": "urn:xoev-de:bmk:standard:xbau_2.2#baugenehmigung.antrag.0200",
  "mimeType": "application/xml"
}
```
